==> kidbit_assistant-0.4.tar.gz: kidbit_assistant-0.4/setup.py <==
import setuptools

setuptools.setup(
  name = 'kidbit_assistant',         # How you named your package folder (MyLib)
  version = '0.4',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Design your Own Assistant',   # Give a short description about your library
  author = 'KidBit',                   # Type in your name
  author_email = 'kidbitacademy@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/KidBit-Academy/kidbit_assistant',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/KidBit-Academy/kidbit_assistant/archive/refs/tags/v1.0.4.tar.gz',    # I explain this later on
  keywords = ['ALEXA', 'BOT', 'CODING', 'KIDS', 'KIDBIT'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'beautifulsoup4==4.10.0',
          'certifi==2021.10.8',
          'charset-normalizer==2.0.12',
          'click==8.0.4',
          'dateparser==1.1.0',
          'feedparser==6.0.8',
          'fuzzywuzzy==0.18.0',
          'gnewsclient==1.12',
          'GoogleNews==1.6.0',
          'gTTS==2.2.3',
          'idna==3.3',
          'MouseInfo==0.1.3',
          'Pillow==9.0.1',
          'PyAudio==0.2.11',
          'PyAutoGUI==0.9.53',
          'PyGetWindow==0.0.9',
          'pyjokes==0.6.0',
          'PyMsgBox==1.0.9',
          'pyobjc==8.4',
          'pyobjc-core==8.4',
          'pyobjc-framework-Accounts==8.4',
          'pyobjc-framework-AddressBook==8.4',
          'pyobjc-framework-AdSupport==8.4',
          'pyobjc-framework-AppleScriptKit==8.4',
          'pyobjc-framework-AppleScriptObjC==8.4',
          'pyobjc-framework-ApplicationServices==8.4',
          'pyobjc-framework-AudioVideoBridging==8.4',
          'pyobjc-framework-AuthenticationServices==8.4',
          'pyobjc-framework-AutomaticAssessmentConfiguration==8.4',
          'pyobjc-framework-Automator==8.4',
          'pyobjc-framework-AVFoundation==8.4',
          'pyobjc-framework-AVKit==8.4',
          'pyobjc-framework-BusinessChat==8.4',
          'pyobjc-framework-CalendarStore==8.4',
          'pyobjc-framework-CFNetwork==8.4',
          'pyobjc-framework-CloudKit==8.4',
          'pyobjc-framework-Cocoa==8.4',
          'pyobjc-framework-Collaboration==8.4',
          'pyobjc-framework-ColorSync==8.4',
          'pyobjc-framework-Contacts==8.4',
          'pyobjc-framework-ContactsUI==8.4',
          'pyobjc-framework-CoreAudio==8.4',
          'pyobjc-framework-CoreAudioKit==8.4',
          'pyobjc-framework-CoreBluetooth==8.4',
          'pyobjc-framework-CoreData==8.4',
          'pyobjc-framework-CoreHaptics==8.4',
          'pyobjc-framework-CoreLocation==8.4',
          'pyobjc-framework-CoreMedia==8.4',
          'pyobjc-framework-CoreMediaIO==8.4',
          'pyobjc-framework-CoreMIDI==8.4',
          'pyobjc-framework-CoreML==8.4',
          'pyobjc-framework-CoreMotion==8.4',
          'pyobjc-framework-CoreServices==8.4',
          'pyobjc-framework-CoreSpotlight==8.4',
          'pyobjc-framework-CoreText==8.4',
          'pyobjc-framework-CoreWLAN==8.4',
          'pyobjc-framework-CryptoTokenKit==8.4',
          'pyobjc-framework-DeviceCheck==8.4',
          'pyobjc-framework-DictionaryServices==8.4',
          'pyobjc-framework-DiscRecording==8.4',
          'pyobjc-framework-DiscRecordingUI==8.4',
          'pyobjc-framework-DiskArbitration==8.4',
          'pyobjc-framework-DVDPlayback==8.4',
          'pyobjc-framework-EventKit==8.4',
          'pyobjc-framework-ExceptionHandling==8.4',
          'pyobjc-framework-ExecutionPolicy==8.4',
          'pyobjc-framework-ExternalAccessory==8.4',
          'pyobjc-framework-FileProvider==8.4',
          'pyobjc-framework-FileProviderUI==8.4',
          'pyobjc-framework-FinderSync==8.4',
          'pyobjc-framework-FSEvents==8.4',
          'pyobjc-framework-GameCenter==8.4',
          'pyobjc-framework-GameController==8.4',
          'pyobjc-framework-GameKit==8.4',
          'pyobjc-framework-GameplayKit==8.4',
          'pyobjc-framework-ImageCaptureCore==8.4',
          'pyobjc-framework-IMServicePlugIn==8.4',
          'pyobjc-framework-InputMethodKit==8.4',
          'pyobjc-framework-InstallerPlugins==8.4',
          'pyobjc-framework-InstantMessage==8.4',
          'pyobjc-framework-Intents==8.4',
          'pyobjc-framework-IOSurface==8.4',
          'pyobjc-framework-iTunesLibrary==8.4',
          'pyobjc-framework-LatentSemanticMapping==8.4',
          'pyobjc-framework-LaunchServices==8.4',
          'pyobjc-framework-libdispatch==8.4',
          'pyobjc-framework-LinkPresentation==8.4',
          'pyobjc-framework-LocalAuthentication==8.4',
          'pyobjc-framework-MapKit==8.4',
          'pyobjc-framework-MediaAccessibility==8.4',
          'pyobjc-framework-MediaLibrary==8.4',
          'pyobjc-framework-MediaPlayer==8.4',
          'pyobjc-framework-MediaToolbox==8.4',
          'pyobjc-framework-Metal==8.4',
          'pyobjc-framework-MetalKit==8.4',
          'pyobjc-framework-MetalPerformanceShaders==8.4',
          'pyobjc-framework-ModelIO==8.4',
          'pyobjc-framework-MultipeerConnectivity==8.4',
          'pyobjc-framework-NaturalLanguage==8.4',
          'pyobjc-framework-NetFS==8.4',
          'pyobjc-framework-Network==8.4',
          'pyobjc-framework-NetworkExtension==8.4',
          'pyobjc-framework-NotificationCenter==8.4',
          'pyobjc-framework-OpenDirectory==8.4',
          'pyobjc-framework-OSAKit==8.4',
          'pyobjc-framework-OSLog==8.4',
          'pyobjc-framework-PencilKit==8.4',
          'pyobjc-framework-Photos==8.4',
          'pyobjc-framework-PhotosUI==8.4',
          'pyobjc-framework-PreferencePanes==8.4',
          'pyobjc-framework-PushKit==8.4',
          'pyobjc-framework-Quartz==8.4',
          'pyobjc-framework-QuickLookThumbnailing==8.4',
          'pyobjc-framework-SafariServices==8.4',
          'pyobjc-framework-SceneKit==8.4',
          'pyobjc-framework-ScreenSaver==8.4',
          'pyobjc-framework-ScriptingBridge==8.4',
          'pyobjc-framework-SearchKit==8.4',
          'pyobjc-framework-Security==8.4',
          'pyobjc-framework-SecurityFoundation==8.4',
          'pyobjc-framework-SecurityInterface==8.4',
          'pyobjc-framework-ServiceManagement==8.4',
          'pyobjc-framework-Social==8.4',
          'pyobjc-framework-SoundAnalysis==8.4',
          'pyobjc-framework-Speech==8.4',
          'pyobjc-framework-SpriteKit==8.4',
          'pyobjc-framework-StoreKit==8.4',
          'pyobjc-framework-SyncServices==8.4',
          'pyobjc-framework-SystemConfiguration==8.4',
          'pyobjc-framework-SystemExtensions==8.4',
          'pyobjc-framework-UserNotifications==8.4',
          'pyobjc-framework-VideoSubscriberAccount==8.4',
          'pyobjc-framework-VideoToolbox==8.4',
          'pyobjc-framework-Vision==8.4',
          'pyobjc-framework-WebKit==8.4',
          'pyperclip==1.8.2',
          'PyRect==0.1.4',
          'PyScreeze==0.1.28',
          'python-dateutil==2.8.2',
          'python-Levenshtein==0.12.2',
          'pyttsx3==2.90',
          'pytweening==1.0.4',
          'pytz==2021.3',
          'pytz-deprecation-shim==0.1.0.post0',
          'pywhatkit==5.3',
          'regex==2022.3.2',
          'requests==2.27.1',
          'rubicon-objc==0.4.2',
          'sgmllib3k==1.0.0',
          'six==1.16.0',
          'soupsieve==2.3.1',
          'SpeechRecognition==3.8.1',
          'tzdata==2021.5',
          'tzlocal==4.1',
          'urllib3==1.26.8',
          'wikipedia==1.4.0'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
  packages=["kidbit_assistant"],
  python_requires=">=3.6",
)

==> kidbit_assistant-1.0.5.tar.gz: kidbit_assistant-1.0.5/setup.py <==
import setuptools

version = '1.0.5'
setuptools.setup(
  name = 'kidbit_assistant',
  version = version,
  license='MIT',
  description = 'Design your Own Assistant',
  author = 'KidBit',
  author_email = 'kidbitacademy@gmail.com',   
  url = 'https://github.com/KidBit-Academy/kidbit_assistant',
  download_url = 'https://github.com/KidBit-Academy/kidbit_assistant/archive/refs/tags/v' + version + '.tar.gz',
  keywords = ['ALEXA', 'BOT', 'CODING', 'KIDS', 'KIDBIT'],  
  install_requires=[        
          'beautifulsoup4==4.10.0',
          'certifi==2021.10.8',
          'charset-normalizer==2.0.12',
          'click==8.0.4',
          'dateparser==1.1.0',
          'feedparser==6.0.8',
          'fuzzywuzzy==0.18.0',
          'gnewsclient==1.12',
          'GoogleNews==1.6.0',
          'gTTS==2.2.3',
          'idna==3.3',
          'MouseInfo==0.1.3',
          'Pillow==9.0.1',
          'PyAudio==0.2.11',
          'PyAutoGUI==0.9.53',
          'PyGetWindow==0.0.9',
          'pyjokes==0.6.0',
          'PyMsgBox==1.0.9',
          'pyobjc==8.4',
          'pyobjc-core==8.4',
          'pyobjc-framework-Accounts==8.4',
          'pyobjc-framework-AddressBook==8.4',
          'pyobjc-framework-AdSupport==8.4',
          'pyobjc-framework-AppleScriptKit==8.4',
          'pyobjc-framework-AppleScriptObjC==8.4',
          'pyobjc-framework-ApplicationServices==8.4',
          'pyobjc-framework-AudioVideoBridging==8.4',
          'pyobjc-framework-AuthenticationServices==8.4',
          'pyobjc-framework-AutomaticAssessmentConfiguration==8.4',
          'pyobjc-framework-Automator==8.4',
          'pyobjc-framework-AVFoundation==8.4',
          'pyobjc-framework-AVKit==8.4',
          'pyobjc-framework-BusinessChat==8.4',
          'pyobjc-framework-CalendarStore==8.4',
          'pyobjc-framework-CFNetwork==8.4',
          'pyobjc-framework-CloudKit==8.4',
          'pyobjc-framework-Cocoa==8.4',
          'pyobjc-framework-Collaboration==8.4',
          'pyobjc-framework-ColorSync==8.4',
          'pyobjc-framework-Contacts==8.4',
          'pyobjc-framework-ContactsUI==8.4',
          'pyobjc-framework-CoreAudio==8.4',
          'pyobjc-framework-CoreAudioKit==8.4',
          'pyobjc-framework-CoreBluetooth==8.4',
          'pyobjc-framework-CoreData==8.4',
          'pyobjc-framework-CoreHaptics==8.4',
          'pyobjc-framework-CoreLocation==8.4',
          'pyobjc-framework-CoreMedia==8.4',
          'pyobjc-framework-CoreMediaIO==8.4',
          'pyobjc-framework-CoreMIDI==8.4',
          'pyobjc-framework-CoreML==8.4',
          'pyobjc-framework-CoreMotion==8.4',
          'pyobjc-framework-CoreServices==8.4',
          'pyobjc-framework-CoreSpotlight==8.4',
          'pyobjc-framework-CoreText==8.4',
          'pyobjc-framework-CoreWLAN==8.4',
          'pyobjc-framework-CryptoTokenKit==8.4',
          'pyobjc-framework-DeviceCheck==8.4',
          'pyobjc-framework-DictionaryServices==8.4',
          'pyobjc-framework-DiscRecording==8.4',
          'pyobjc-framework-DiscRecordingUI==8.4',
          'pyobjc-framework-DiskArbitration==8.4',
          'pyobjc-framework-DVDPlayback==8.4',
          'pyobjc-framework-EventKit==8.4',
          'pyobjc-framework-ExceptionHandling==8.4',
          'pyobjc-framework-ExecutionPolicy==8.4',
          'pyobjc-framework-ExternalAccessory==8.4',
          'pyobjc-framework-FileProvider==8.4',
          'pyobjc-framework-FileProviderUI==8.4',
          'pyobjc-framework-FinderSync==8.4',
          'pyobjc-framework-FSEvents==8.4',
          'pyobjc-framework-GameCenter==8.4',
          'pyobjc-framework-GameController==8.4',
          'pyobjc-framework-GameKit==8.4',
          'pyobjc-framework-GameplayKit==8.4',
          'pyobjc-framework-ImageCaptureCore==8.4',
          'pyobjc-framework-IMServicePlugIn==8.4',
          'pyobjc-framework-InputMethodKit==8.4',
          'pyobjc-framework-InstallerPlugins==8.4',
          'pyobjc-framework-InstantMessage==8.4',
          'pyobjc-framework-Intents==8.4',
          'pyobjc-framework-IOSurface==8.4',
          'pyobjc-framework-iTunesLibrary==8.4',
          'pyobjc-framework-LatentSemanticMapping==8.4',
          'pyobjc-framework-LaunchServices==8.4',
          'pyobjc-framework-libdispatch==8.4',
          'pyobjc-framework-LinkPresentation==8.4',
          'pyobjc-framework-LocalAuthentication==8.4',
          'pyobjc-framework-MapKit==8.4',
          'pyobjc-framework-MediaAccessibility==8.4',
          'pyobjc-framework-MediaLibrary==8.4',
          'pyobjc-framework-MediaPlayer==8.4',
          'pyobjc-framework-MediaToolbox==8.4',
          'pyobjc-framework-Metal==8.4',
          'pyobjc-framework-MetalKit==8.4',
          'pyobjc-framework-MetalPerformanceShaders==8.4',
          'pyobjc-framework-ModelIO==8.4',
          'pyobjc-framework-MultipeerConnectivity==8.4',
          'pyobjc-framework-NaturalLanguage==8.4',
          'pyobjc-framework-NetFS==8.4',
          'pyobjc-framework-Network==8.4',
          'pyobjc-framework-NetworkExtension==8.4',
          'pyobjc-framework-NotificationCenter==8.4',
          'pyobjc-framework-OpenDirectory==8.4',
          'pyobjc-framework-OSAKit==8.4',
          'pyobjc-framework-OSLog==8.4',
          'pyobjc-framework-PencilKit==8.4',
          'pyobjc-framework-Photos==8.4',
          'pyobjc-framework-PhotosUI==8.4',
          'pyobjc-framework-PreferencePanes==8.4',
          'pyobjc-framework-PushKit==8.4',
          'pyobjc-framework-Quartz==8.4',
          'pyobjc-framework-QuickLookThumbnailing==8.4',
          'pyobjc-framework-SafariServices==8.4',
          'pyobjc-framework-SceneKit==8.4',
          'pyobjc-framework-ScreenSaver==8.4',
          'pyobjc-framework-ScriptingBridge==8.4',
          'pyobjc-framework-SearchKit==8.4',
          'pyobjc-framework-Security==8.4',
          'pyobjc-framework-SecurityFoundation==8.4',
          'pyobjc-framework-SecurityInterface==8.4',
          'pyobjc-framework-ServiceManagement==8.4',
          'pyobjc-framework-Social==8.4',
          'pyobjc-framework-SoundAnalysis==8.4',
          'pyobjc-framework-Speech==8.4',
          'pyobjc-framework-SpriteKit==8.4',
          'pyobjc-framework-StoreKit==8.4',
          'pyobjc-framework-SyncServices==8.4',
          'pyobjc-framework-SystemConfiguration==8.4',
          'pyobjc-framework-SystemExtensions==8.4',
          'pyobjc-framework-UserNotifications==8.4',
          'pyobjc-framework-VideoSubscriberAccount==8.4',
          'pyobjc-framework-VideoToolbox==8.4',
          'pyobjc-framework-Vision==8.4',
          'pyobjc-framework-WebKit==8.4',
          'pyperclip==1.8.2',
          'PyRect==0.1.4',
          'PyScreeze==0.1.28',
          'python-dateutil==2.8.2',
          'python-Levenshtein==0.12.2',
          'pyttsx3==2.90',
          'pytweening==1.0.4',
          'pytz==2021.3',
          'pytz-deprecation-shim==0.1.0.post0',
          'pywhatkit==5.3',
          'regex==2022.3.2',
          'requests==2.27.1',
          'rubicon-objc==0.4.2',
          'sgmllib3k==1.0.0',
          'six==1.16.0',
          'soupsieve==2.3.1',
          'SpeechRecognition==3.8.1',
          'tzdata==2021.5',
          'tzlocal==4.1',
          'urllib3==1.26.8',
          'wikipedia==1.4.0'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
  packages=["kidbit_assistant"],
  python_requires=">=3.6",
)
